﻿using System;
using System.Linq;
using DotNetCoreRpc.Client;
using DotNetCoreRpc.Core;
using IRpcService;
using IRpcService.Dtos;
using Microsoft.Extensions.DependencyInjection;

namespace ClientDemo
{
    class Program
    {
        static void Main(string[] args)
        {
            IServiceCollection services = new ServiceCollection();
            //*注册DotNetCoreRpcClient
            services.AddDotNetCoreRpcClient()
            //*通信基于HttpClientFactory,自行注册即可
            .AddHttpClient("WebDemo", client => { client.BaseAddress = new Uri("http://localhost:13285/"); });

            IServiceProvider serviceProvider = services.BuildServiceProvider();

            //*RpcClient使用这个类创建具体服务代理
            RpcClient rpcClient = serviceProvider.GetRequiredService<RpcClient>();

            //IPersonService是我引入的服务包interface，需要提供ServiceName,即AddHttpClient的名称
            IPersonService personService = rpcClient.CreateClient<IPersonService>("WebDemo");

            PersonDto personDto = new PersonDto
            {
                Id = 1,
                Name = "yi念之间",
                Address = "中国",
                BirthDay = new DateTime(2000,12,12),
                IsMarried = true,
                Tel = 88888888888
            };
            bool addFlag = personService.Add(personDto);
            Console.WriteLine($"添加结果=[{addFlag}]");

            var person = personService.Get(personDto.Id);
            Console.WriteLine($"获取person结果=[{person.ToJson()}]");

            var persons = personService.GetAll();
            Console.WriteLine($"获取persons结果=[{persons.ToList().ToJson()}]");

            personService.Delete(person.Id);
            Console.WriteLine($"删除完成");

            Console.ReadLine();
        }
    }
}
